@@ -65,6 +65,18 @@ def add_param_descriptions(params_dict):
     params_dict['delete']['documents'] = "Files that exist in the " \
         "destination but not in the source are deleted during sync."
 
+    params_dict['follow-symlinks']['documents'] = "Symbolic links are " \
+    "followed only when uploading to S3 from the local filesystem. Note" \
+    " that S3 does not support symbolic links, so the contents of the link" \
+    " target are uploaded under the name of the link.  When neither " \
+    "``--follow-symlinks`` nor ``--no-follow-symlinks`` is specifed, " \
+    " the default is to follow symlinks."
+
+    params_dict['no-follow-symlinks']['documents'] = "Symbolic links are " \
+    "ignored when uploading to S3 from the local filesystem. When neither " \
+    "``--follow-symlinks`` nor ``--no-follow-symlinks`` is specifed, " \
+    " the default is to follow symlinks."    
+
     params_dict['exclude']['documents'] = "Exclude all files or objects" \
         " from the command that matches the specified pattern."
 
